@@ -8,6 +8,7 @@ from typing import Optional
 import pulumi
 import pulumi_aws as aws
 import pulumi_aws_native as aws_native
+import pulumi_random as random
 
 
 class Events:
@@ -135,6 +136,8 @@ class Events:
         resource_name = aws.get_arn(arn=target_arn).resource
         resource_type = aws.get_arn(arn=target_arn).service
 
+        random_pet = random.RandomPet(f"{name}-pet", length=2)
+
         # If the event is being transformed, there are two variables that are required
         # `input_paths` and `input_template`
         if input_paths and input_template:
@@ -154,8 +157,8 @@ class Events:
 
         # https://www.pulumi.com/registry/packages/aws/api-docs/cloudwatch/eventrule/
         rule = aws.cloudwatch.EventRule(
-            f"{name}-EventRule",
-            name = name,
+            f"{name}-rule",
+            name = f"{name}-{random_pet}",
             description = description,
             event_bus_name = event_bus_name,
             is_enabled = True,
@@ -168,7 +171,7 @@ class Events:
         def general_event():
             # https://www.pulumi.com/registry/packages/aws/api-docs/cloudwatch/eventtarget/
             aws.cloudwatch.EventTarget(
-                f"{name}-RuleTarget",
+                f"{name}-rule-target",
                 arn = target_arn,
                 event_bus_name = event_bus_name,
                 rule = rule.name,
@@ -186,7 +189,7 @@ class Events:
 
             # https://www.pulumi.com/registry/packages/aws/api-docs/lambda/permission/
             aws.lambda_.Permission(
-                f"{name}-LambdaPermission",
+                f"{name}-lambda-permission",
                 action = "lambda:InvokeFunction",
                 function = resource_name,
                 principal = "events.amazonaws.com",
@@ -195,7 +198,7 @@ class Events:
             )
 
             aws.cloudwatch.EventTarget(
-                f"{name}-RuleTarget",
+                f"{name}-rule-tTarget",
                 arn = target_arn,
                 event_bus_name = event_bus_name,
                 rule = rule.arn,
@@ -238,7 +241,7 @@ class Events:
 
                 # https://www.pulumi.com/registry/packages/aws-native/api-docs/iam/role/
                 event_bus_role = aws_native.iam.Role(
-                    f"{name}-Role",
+                    f"{name}-role",
                     policies = [aws_native.iam.RolePolicyArgs(
                         policy_name = f"{name}-PutEventBus",
                         policy_document = event_bus_policy.json
@@ -248,7 +251,7 @@ class Events:
 
                 # https://www.pulumi.com/registry/packages/aws/api-docs/cloudwatch/eventtarget/
                 aws.cloudwatch.EventTarget(
-                    f"{name}-RuleTarget",
+                    f"{name}-rule-target",
                     arn = target_arn,
                     event_bus_name = event_bus_name,
                     rule = rule.name,
@@ -292,7 +295,7 @@ class Events:
 
                 # https://www.pulumi.com/registry/packages/aws-native/api-docs/iam/role/
                 destination_role = aws_native.iam.Role(
-                    f"{name}-Role",
+                    f"{name}-role",
                     policies = [aws_native.iam.RolePolicyArgs(
                         policy_name = f"{name}-InvokeApiDestination",
                         policy_document = api_destination_policy.json
@@ -302,7 +305,7 @@ class Events:
 
                 # https://www.pulumi.com/registry/packages/aws/api-docs/cloudwatch/eventtarget/
                 aws.cloudwatch.EventTarget(
-                    f"{name}RuleTarget",
+                    f"{name}-rule-target",
                     arn = target_arn,
                     event_bus_name = event_bus_name,
                     rule = rule.name,
@@ -345,7 +348,7 @@ class Events:
 
             # https://www.pulumi.com/registry/packages/aws-native/api-docs/iam/role/
             step_function_role = aws_native.iam.Role(
-                f"{name}-Role",
+                f"{name}-role",
                 policies = [aws_native.iam.RolePolicyArgs(
                     policy_name = f"{name}-InvokeStepFunction",
                     policy_document = step_function_policy.json
@@ -355,7 +358,7 @@ class Events:
 
             # https://www.pulumi.com/registry/packages/aws/api-docs/cloudwatch/eventtarget/
             aws.cloudwatch.EventTarget(
-                f"{name}-RuleTarget",
+                f"{name}-rule-target",
                 arn = target_arn,
                 event_bus_name = event_bus_name,
                 rule = rule.name,
@@ -398,7 +401,7 @@ class Events:
 
             # https://www.pulumi.com/registry/packages/aws-native/api-docs/iam/role/
             kinesis_role = aws_native.iam.Role(
-                f"{name}-Role",
+                f"{name}-role",
                 policies = [aws_native.iam.RolePolicyArgs(
                     policy_name = f"{name}-InvokePutRecordStream",
                     policy_document = kinesis_stream_policy.json
@@ -408,7 +411,7 @@ class Events:
 
             # https://www.pulumi.com/registry/packages/aws/api-docs/cloudwatch/eventtarget/
             aws.cloudwatch.EventTarget(
-                f"{name}RuleTarget",
+                f"{name}-rule-target",
                 arn = target_arn,
                 event_bus_name = event_bus_name,
                 rule = rule.name,
@@ -462,7 +465,7 @@ class Events:
 
             # https://www.pulumi.com/registry/packages/aws/api-docs/cloudwatch/eventtarget/
             aws.cloudwatch.EventTarget(
-                f"{name}-RuleTarget",
+                f"{name}-rule-target",
                 arn = target_arn,
                 event_bus_name = event_bus_name,
                 rule = rule.name,
@@ -483,15 +486,15 @@ class Events:
             print("Logs Target --> Creating Cloudwatch Log Group")
 
             # https://www.pulumi.com/registry/packages/aws-native/api-docs/logs/loggroup/
-            log_group = aws_native.logs.LogGroup(
+            log_group = aws.cloudwatch.LogGroup(
                 f"{name}-logs",
-                log_group_name = f"/aws/events/{name}-logs",
+                name = f"/aws/events/{name}-logs",
                 retention_in_days = 1
             )
 
             # https://www.pulumi.com/registry/packages/aws/api-docs/cloudwatch/eventtarget/
             aws.cloudwatch.EventTarget(
-                f"{name}-LogsRuleTarget",
+                f"{name}-logs-rule-target",
                 arn = log_group.arn,
                 event_bus_name = event_bus_name,
                 rule = rule.name,
